@@ -4,9 +4,9 @@
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
 use v5.36;
-use Object::Pad 0.66;
+use Object::Pad 0.800;
 
-class App::perl::distrolint::Check::Editorconfig;
+class App::perl::distrolint::Check::Editorconfig 0.02;
 
 use constant DESC => "check that .editorconfig exists";
 use constant SORT => 5;
